@@ -222,8 +222,18 @@ sub add_attribute {
             or $self->throw_error('You must provide a name for the attribute');
 
         if ($name =~ s/^\+//) { # inherited attributes
-            my $inherited_attr = $self->find_attribute_by_name($name)
-                or $self->throw_error("Could not find an attribute by the name of '$name' to inherit from in ".$self->name);
+            # Workaround for https://github.com/gfx/p5-Mouse/issues/64
+            # Do not use find_attribute_by_name to avoid problems with cached attributes list
+            # because we're about to change it anyway
+            my $inherited_attr;
+            foreach my $i ( @{ $self->_calculate_all_attributes } ) {
+                if ( $i->name eq $name ) {
+                    $inherited_attr = $i;
+                    last;
+                }
+            }
+            $self->throw_error("Could not find an attribute by the name of '$name' to inherit from in ".$self->name)
+                unless $inherited_attr;
 
             $attr = $inherited_attr->clone_and_inherit_options(%args);
         }
@@ -470,7 +480,7 @@ Mouse::Meta::Class - The Mouse class metaclass
 
 =head1 VERSION
 
-This document describes Mouse version v2.4.6
+This document describes Mouse version v2.4.7
 
 =head1 DESCRIPTION
 
